@@ -1,19 +1,7 @@
 /*
-  Copyright (C) 2009 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2009 Bertjan Broeksema <broeksema@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License version 2 as published by the Free Software Foundation.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "mboxtest.h"
@@ -293,7 +281,6 @@ void MboxTest::testBlankLines()
         mbox1.appendMessage(mail);
         mbox1.save();
 
-        MBox mbox2;
         QVERIFY(mbox1.setLockType(MBox::None));
         QVERIFY(mbox1.load(fileName()));
         QCOMPARE(mbox1.entries().size(), 3);
@@ -503,6 +490,7 @@ void MboxTest::testReadOnlyMbox()
 void MboxTest::cleanupTestCase()
 {
     mTempDir->remove();
+    delete mTempDir;
 }
 
 //---------------------------------------------------------------------
